# PhyloRank

<b>[This project is in active development, you are welcomed to use this software though it may be unstable.]</b>

[![version status](https://img.shields.io/pypi/v/phylorank.svg)](https://pypi.python.org/pypi/phylorank)
[![downloads](https://img.shields.io/pypi/dm/phylorank.svg)](https://pypi.python.org/pypi/phylorank)

PhyloRank is ...

## Install

The simplest way to install this package is through pip:
> sudo pip install phylorank

## Cite

If you find this package useful, please cite this git repository (https://github.com/dparks1134/PhyloRank)

## Copyright

Copyright © 2015 Donovan Parks. See LICENSE for further details.
